# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: disable=too-many-lines


def term_show(client,
              publisher,
              product,
              plan):
    return client.get(offer_type="virtualmachine",
                      publisher_id=publisher,
                      offer_id=product,
                      plan_id=plan)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

# pylint: disable=line-too-long,too-many-lines

from azure.cli.core.commands import DeploymentOutputLongRunningOperation
from azure.cli.core.commands.arm import (
    deployment_validate_table_format, handle_template_based_exception)
from azure.cli.core.commands import CliCommandType
from azure.cli.core.profiles import get_api_version, ResourceType

from azure.cli.command_modules.network.azure_stack._client_factory import (
    cf_dns_mgmt_record_sets, cf_dns_mgmt_zones,
    cf_dns_references)
from azure.cli.command_modules.network.azure_stack._format import (
    transform_dns_record_set_output,
    transform_dns_record_set_table_output, transform_dns_zone_table_output)
from azure.cli.command_modules.network.azure_stack._validators import (
    process_lb_create_namespace,
    process_vpn_connection_create_namespace)


# pylint: disable=too-many-locals, too-many-statements
def load_command_table(self, _):

    # region Command Types

    network_dns_zone_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.dns.operations#ZonesOperations.{}',
        client_factory=cf_dns_mgmt_zones,
        resource_type=ResourceType.MGMT_NETWORK_DNS
    )

    network_dns_record_set_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.dns.operations#RecordSetsOperations.{}',
        client_factory=cf_dns_mgmt_record_sets,
        resource_type=ResourceType.MGMT_NETWORK_DNS
    )

    network_dns_reference_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.dns.operations#DnsResourceReferenceOperations.{}',
        client_factory=cf_dns_references,
        resource_type=ResourceType.MGMT_NETWORK_DNS,
        min_api='2018-05-01'
    )

    # region DNS
    with self.command_group('network dns', network_dns_reference_sdk, resource_type=ResourceType.MGMT_NETWORK_DNS) as g:
        g.command('list-references', 'get_by_target_resources')

    with self.command_group('network dns zone', network_dns_zone_sdk) as g:
        g.command('delete', 'begin_delete', confirmation=True)
        g.show_command('show', 'get', table_transformer=transform_dns_zone_table_output)
        g.custom_command('list', 'list_dns_zones', table_transformer=transform_dns_zone_table_output)
        g.custom_command('import', 'import_zone')
        g.custom_command('export', 'export_zone')
        g.custom_command('create', 'create_dns_zone', client_factory=cf_dns_mgmt_zones)
        g.generic_update_command('update', custom_func_name='update_dns_zone')

    with self.command_group('network dns record-set') as g:
        g.custom_command('list', 'list_dns_record_set', client_factory=cf_dns_mgmt_record_sets, transform=transform_dns_record_set_output)

    api_version = str(get_api_version(self.cli_ctx, ResourceType.MGMT_NETWORK_DNS))
    api_version = api_version.replace('-', '_')
    dns_doc_string = 'azure.mgmt.dns.v' + api_version + '.operations#RecordSetsOperations.create_or_update'

    supported_records = ['a', 'aaaa', 'mx', 'ns', 'ptr', 'srv', 'txt']
    if self.supported_api_version(resource_type=ResourceType.MGMT_NETWORK_DNS, min_api='2018-02-01'):
        supported_records.append('caa')
    for record in supported_records:
        with self.command_group('network dns record-set {}'.format(record), network_dns_record_set_sdk, resource_type=ResourceType.MGMT_NETWORK_DNS) as g:
            g.show_command('show', 'get', transform=transform_dns_record_set_output)
            g.command('delete', 'delete', confirmation=True)
            g.custom_command('list', 'list_dns_record_set', client_factory=cf_dns_mgmt_record_sets, transform=transform_dns_record_set_output, table_transformer=transform_dns_record_set_table_output)
            g.custom_command('create', 'create_dns_record_set', transform=transform_dns_record_set_output, doc_string_source=dns_doc_string)
            g.custom_command('add-record', 'add_dns_{}_record'.format(record), transform=transform_dns_record_set_output)
            g.custom_command('remove-record', 'remove_dns_{}_record'.format(record), transform=transform_dns_record_set_output)
            g.generic_update_command('update', custom_func_name='update_dns_record_set', transform=transform_dns_record_set_output)

    with self.command_group('network dns record-set soa', network_dns_record_set_sdk) as g:
        g.show_command('show', 'get', transform=transform_dns_record_set_output)
        g.custom_command('update', 'update_dns_soa_record', transform=transform_dns_record_set_output)

    with self.command_group('network dns record-set cname', network_dns_record_set_sdk) as g:
        g.show_command('show', 'get', transform=transform_dns_record_set_output)
        g.command('delete', 'delete', confirmation=True)
        g.custom_command('list', 'list_dns_record_set', client_factory=cf_dns_mgmt_record_sets, transform=transform_dns_record_set_output, table_transformer=transform_dns_record_set_table_output)
        g.custom_command('create', 'create_dns_record_set', transform=transform_dns_record_set_output, doc_string_source=dns_doc_string)
        g.custom_command('set-record', 'add_dns_cname_record', transform=transform_dns_record_set_output)
        g.custom_command('remove-record', 'remove_dns_cname_record', transform=transform_dns_record_set_output)
    # endregion

    # region LoadBalancers
    with self.command_group('network lb') as g:
        g.custom_command('create', 'create_load_balancer',
                         transform=DeploymentOutputLongRunningOperation(self.cli_ctx),
                         supports_no_wait=True,
                         table_transformer=deployment_validate_table_format,
                         validator=process_lb_create_namespace,
                         exception_handler=handle_template_based_exception)
    # endregion

    # region VirtualNetworkGatewayConnections
    with self.command_group('network vpn-connection') as g:
        g.custom_command('create', 'create_vpn_connection', transform=DeploymentOutputLongRunningOperation(self.cli_ctx), table_transformer=deployment_validate_table_format, validator=process_vpn_connection_create_namespace, exception_handler=handle_template_based_exception)
    # endregion

    # region PrivateLinkResource and PrivateEndpointConnection
    plr_and_pec_custom = CliCommandType(operations_tmpl='azure.cli.command_modules.network.azure_stack.private_link_resource_and_endpoint_connections.custom#{}')
    with self.command_group('network private-link-resource', custom_command_type=plr_and_pec_custom) as g:
        g.custom_show_command('list', 'list_private_link_resource')
    with self.command_group('network private-endpoint-connection', custom_command_type=plr_and_pec_custom) as g:
        g.custom_command('approve', 'approve_private_endpoint_connection')
        g.custom_command('reject', 'reject_private_endpoint_connection')
        g.custom_command('delete', 'remove_private_endpoint_connection', confirmation=True)
        g.custom_show_command('show', 'show_private_endpoint_connection')
        g.custom_command('list', 'list_private_endpoint_connection')
    # endregion



# coding=utf-8
# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.help_files import helps


helps['aks'] = """
type: group
short-summary: Manage Azure Kubernetes Services.
"""

helps["aks check-acr"] = """
type: command
short-summary: Validate an ACR is accessible from an AKS cluster.
parameters:
  - name: --acr
    short-summary: The FQDN of the ACR.
  - name: --node-name
    short-summary: The name of a specific node to perform acr pull test checks. If not specified, it will be checked on a random node.
examples:
  - name: Validate the ACR is accessible from the AKS cluster.
    text: az aks check-acr --name MyManagedCluster --resource-group MyResourceGroup --acr myacr.azurecr.io
    crafted: true
"""

helps['aks browse'] = """
type: command
short-summary: Show the dashboard for a Kubernetes cluster in a web browser.
parameters:
  - name: --disable-browser
    type: bool
    short-summary: Don't launch a web browser after establishing port-forwarding.
    long-summary: Add this argument when launching a web browser manually, or for automated testing.
  - name: --listen-port
    short-summary: The listening port for the dashboard.
    long-summary: Add this argument when the default listening port is used by another process or unavailable.
  - name: --listen-address
    short-summary: The listening address for the dashboard.
    long-summary: Add this argument to listen on a specific IP address.
examples:
  - name: Show the dashboard for a Kubernetes cluster in a web browser. (autogenerated)
    text: az aks browse --name MyManagedCluster --resource-group MyResourceGroup
    crafted: true
"""

helps['aks create'] = """
type: command
short-summary: Create a new managed Kubernetes cluster.
parameters:
  - name: --generate-ssh-keys
    type: string
    short-summary: Generate SSH public and private key files if missing. The keys will be stored in the ~/.ssh directory.
  - name: --service-principal
    type: string
    short-summary: Service principal used for authentication to Azure APIs.
    long-summary: If not specified, a new service principal is created and cached at $HOME/.azure/aksServicePrincipal.json to be used by subsequent `az aks` commands.
  - name: --skip-subnet-role-assignment
    type: bool
    short-summary: Skip role assignment for subnet (advanced networking).
    long-summary: If specified, please make sure your service principal has the access to your subnet.
  - name: --client-secret
    type: string
    short-summary: Secret associated with the service principal. This argument is required if `--service-principal` is specified.
  - name: --node-vm-size -s
    type: string
    short-summary: Size of Virtual Machines to create as Kubernetes nodes.
  - name: --dns-name-prefix -p
    type: string
    short-summary: Prefix for hostnames that are created. If not specified, generate a hostname using the managed cluster and resource group names.
  - name: --node-count -c
    type: int
    short-summary: Number of nodes in the Kubernetes node pool. After creating a cluster, you can change the size of its node pool with `az aks scale`.
  - name: --zones -z
    type: string array
    short-summary: Availability zones where agent nodes will be placed. Also, to install agent nodes to more than one zones you need to pass zone numbers (1,2 or 3) separated by blanks.  For example -  To have all 3 zones, you are expected to enter `--zones 1 2 3`
  - name: --node-osdisk-size
    type: int
    short-summary: Size in GB of the OS disk for each node in the node pool. Minimum 30 GB.
  - name: --node-osdisk-type
    type: string
    short-summary: "OS disk type to be used for machines in a given agent pool: Ephemeral or Managed. Defaults to 'Ephemeral' when possible in conjunction with VM size and OS disk size. May not be changed for this pool after creation."
  - name: --kubernetes-version -k
    type: string
    short-summary: Version of Kubernetes to use for creating the cluster, such as "1.16.9".
    populator-commands:
      - "`az aks get-versions`"
  - name: --os-sku
    type: string
    short-summary: The OS SKU of the agent node pool. Ubuntu or CBLMariner.
  - name: --ssh-key-value
    type: string
    short-summary: Public key path or key contents to install on node VMs for SSH access. For example, 'ssh-rsa AAAAB...snip...UcyupgH azureuser@linuxvm'.
  - name: --admin-username -u
    type: string
    short-summary: User account to create on node VMs for SSH access.
  - name: --windows-admin-username
    type: string
    short-summary: User account to create on windows node VMs.
    long-summary: |-
      Rules for windows-admin-username:
          - restriction: Cannot end in "."
          - Disallowed values: "administrator", "admin", "user", "user1", "test", "user2", "test1", "user3", "admin1", "1", "123", "a", "actuser", "adm", "admin2", "aspnet", "backup", "console", "david", "guest", "john", "owner", "root", "server", "sql", "support", "support_388945a0", "sys", "test2", "test3", "user4", "user5".
          - Minimum-length: 1 character
          - Max-length: 20 characters
      Reference: https://docs.microsoft.com/dotnet/api/microsoft.azure.management.compute.models.virtualmachinescalesetosprofile.adminusername?view=azure-dotnet
  - name: --windows-admin-password
    type: string
    short-summary: User account password to use on windows node VMs.
    long-summary: |-
      Rules for windows-admin-password:
          - Minimum-length: 14 characters
          - Max-length: 123 characters
          - Complexity requirements: 3 out of 4 conditions below need to be fulfilled
            * Has lower characters
            * Has upper characters
            * Has a digit
            * Has a special character (Regex match [\\W_])
          - Disallowed values:  "abc@123", "P@$$w0rd", "P@ssw0rd", "P@ssword123", "Pa$$word", "pass@word1", "Password!", "Password1", "Password22", "iloveyou!"
      Reference: https://docs.microsoft.com/dotnet/api/microsoft.azure.management.compute.models.virtualmachinescalesetosprofile.adminpassword?view=azure-dotnet
  - name: --enable-ahub
    type: bool
    short-summary: Enable Azure Hybrid User Benefits (AHUB) for Windows VMs.
  - name: --enable-aad
    type: bool
    short-summary: Enable managed AAD feature for cluster.
  - name: --aad-admin-group-object-ids
    type: string
    short-summary: Comma seperated list of aad group object IDs that will be set as cluster admin.
  - name: --aad-client-app-id
    type: string
    short-summary: The ID of an Azure Active Directory client application of type "Native". This application is for user login via kubectl.
    long-summary: --aad-client-app-id is deprecated. See https://aka.ms/aks/aad-legacy for details.
  - name: --aad-server-app-id
    type: string
    short-summary: The ID of an Azure Active Directory server application of type "Web app/API". This application represents the managed cluster's apiserver (Server application).
    long-summary: --aad-server-app-id is deprecated. See https://aka.ms/aks/aad-legacy for details.
  - name: --aad-server-app-secret
    type: string
    short-summary: The secret of an Azure Active Directory server application.
    long-summary: --aad-server-app-secret is deprecated. See https://aka.ms/aks/aad-legacy for details.
  - name: --aad-tenant-id
    type: string
    short-summary: The ID of an Azure Active Directory tenant.
  - name: --dns-service-ip
    type: string
    short-summary: An IP address assigned to the Kubernetes DNS service.
    long-summary: This address must be within the Kubernetes service address range specified by "--service-cidr". For example, 10.0.0.10.
  - name: --docker-bridge-address
    type: string
    short-summary: A specific IP address and netmask for the Docker bridge, using standard CIDR notation.
    long-summary: This address must not be in any Subnet IP ranges, or the Kubernetes service address range. For example, 172.17.0.1/16.
  - name: --load-balancer-sku
    type: string
    short-summary: Azure Load Balancer SKU selection for your cluster. basic or standard. Defaults to 'standard'
    long-summary: Select between Basic or Standard Azure Load Balancer SKU for your AKS cluster.
  - name: --load-balancer-managed-outbound-ip-count
    type: int
    short-summary: Load balancer managed outbound IP count.
    long-summary: Desired number of managed outbound IPs for load balancer outbound connection. Valid for Standard SKU load balancer cluster only.
  - name: --load-balancer-managed-outbound-ipv6-count
    type: int
    short-summary: Load balancer managed outbound IPv6 IP count.
    long-summary: Desired number of managed outbound IPv6 IPs for load balancer outbound connection. Valid for dual-stack (--ip-families IPv4,IPv6) only. If updated, it will wipe off the existing setting on Load balancer managed outbound IPv6 count; Load balancer outbound IP resource IDs and Load balancer outbound IP prefix resource IDs.
  - name: --load-balancer-outbound-ips
    type: string
    short-summary: Load balancer outbound IP resource IDs.
    long-summary: Comma-separated public IP resource IDs for load balancer outbound connection. Valid for Standard SKU load balancer cluster only.
  - name: --load-balancer-outbound-ip-prefixes
    type: string
    short-summary: Load balancer outbound IP prefix resource IDs.
    long-summary: Comma-separated public IP prefix resource IDs for load balancer outbound connection. Valid for Standard SKU load balancer cluster only.
  - name: --load-balancer-outbound-ports
    type: int
    short-summary: Load balancer outbound allocated ports.
    long-summary: Desired static number of outbound ports per VM in the load balancer backend pool. By default, set to 0 which uses the default allocation based on the number of VMs.
  - name: --load-balancer-idle-timeout
    type: int
    short-summary: Load balancer idle timeout in minutes.
    long-summary: Desired idle timeout for load balancer outbound flows, default is 30 minutes. Please specify a value in the range of [4, 100].
  - name: --nat-gateway-managed-outbound-ip-count
    type: int
    short-summary: NAT gateway managed outbound IP count.
    long-summary: Desired number of managed outbound IPs for NAT gateway outbound connection. Please specify a value in the range of [1, 16]. Valid for Standard SKU load balancer cluster with managedNATGateway outbound type only.
  - name: --nat-gateway-idle-timeout
    type: int
    short-summary: NAT gateway idle timeout in minutes.
    long-summary: Desired idle timeout for NAT gateway outbound flows, default is 4 minutes. Please specify a value in the range of [4, 120]. Valid for Standard SKU load balancer cluster with managedNATGateway outbound type only.
  - name: --outbound-type
    type: string
    short-summary: How outbound traffic will be configured for a cluster.
    long-summary: Select between loadBalancer, userDefinedRouting, managedNATGateway and userAssignedNATGateway. If not set, defaults to type loadBalancer. Requires --vnet-subnet-id to be provided with a preconfigured route table and --load-balancer-sku to be Standard.
  - name: --auto-upgrade-channel
    type: string
    short-summary: Specify the upgrade channel for autoupgrade.
  - name: --enable-cluster-autoscaler
    type: bool
    short-summary: Enable cluster autoscaler, default value is false.
    long-summary: If specified, please make sure the kubernetes version is larger than 1.10.6.
  - name: --min-count
    type: int
    short-summary: Minimum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [1, 1000].
  - name: --max-count
    type: int
    short-summary: Maximum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [1, 1000].
  - name: --vm-set-type
    type: string
    short-summary: Agent pool vm set type. VirtualMachineScaleSets or AvailabilitySet. Defaults to 'VirtualMachineScaleSets'
  - name: --enable-addons -a
    type: string
    short-summary: Enable the Kubernetes addons in a comma-separated list.
    long-summary: |-
        These addons are available:
            - http_application_routing : configure ingress with automatic public DNS name creation.
            - monitoring               : turn on Log Analytics monitoring. Uses the Log Analytics Default Workspace if it exists, else creates one.
                                         Specify "--workspace-resource-id" to use an existing workspace.
                                         Specify "--enable-msi-auth-for-monitoring" to use Managed Identity Auth.
                                         Specify "--enable-syslog" to enable syslog data collection from nodes. Note MSI must be enabled
                                         Specify "--data-collection-settings" to configure data collection settings
                                         If monitoring addon is enabled --no-wait argument will have no effect
            - azure-policy             : enable Azure policy. The Azure Policy add-on for AKS enables at-scale enforcements and safeguards on your clusters in a centralized, consistent manner.
                                         Learn more at aka.ms/aks/policy.
            - virtual-node             : enable AKS Virtual Node.
                                         Requires --aci-subnet-name to provide the name of an existing subnet for the Virtual Node to use.
                                         aci-subnet-name must be in the same vnet which is specified by --vnet-subnet-id (required as well).
            - confcom                  : enable confcom addon, this will enable SGX device plugin by default.
            - open-service-mesh        : enable Open Service Mesh addon.
            - azure-keyvault-secrets-provider : enable Azure Keyvault Secrets Provider addon.
  - name: --disable-rbac
    type: bool
    short-summary: Disable Kubernetes Role-Based Access Control.
  - name: --max-pods -m
    type: int
    short-summary: The maximum number of pods deployable to a node.
    long-summary: If not specified, defaults based on network-plugin. 30 for "azure", 110 for "kubenet", or 250 for "none".
  - name: --network-plugin
    type: string
    short-summary: The Kubernetes network plugin to use.
    long-summary: Specify "azure" for routable pod IPs from VNET, "kubenet" for non-routable pod IPs with an overlay network, or "none" for no networking configured. Defaults to "kubenet".
  - name: --network-plugin-mode
    type: string
    short-summary: The network plugin mode to use.
    long-summary: |
        Used to control the mode the network plugin should operate in. For example, "overlay" used with
        --network-plugin=azure will use an overlay network (non-VNET IPs) for pods in the cluster.
  - name: --network-policy
    type: string
    short-summary: The Kubernetes network policy to use.
    long-summary: |
        Using together with "azure" network plugin.
        Specify "azure" for Azure network policy manager and "calico" for calico network policy controller.
        Defaults to "" (network policy disabled).
  - name: --network-dataplane
    type: string
    short-summary: The network dataplane to use.
    long-summary: |
        Network dataplane used in the Kubernetes cluster.
        Specify "azure" to use the Azure dataplane (default) or "cilium" to enable Cilium dataplane.
  - name: --no-ssh-key -x
    type: string
    short-summary: Do not use or create a local SSH key.
    long-summary: To access nodes after creating a cluster with this option, use the Azure Portal.
  - name: --pod-cidr
    type: string
    short-summary: A CIDR notation IP range from which to assign pod IPs when kubenet is used.
    long-summary: This range must not overlap with any Subnet IP ranges. For example, 172.244.0.0/16.
  - name: --service-cidr
    type: string
    short-summary: A CIDR notation IP range from which to assign service cluster IPs.
    long-summary: This range must not overlap with any Subnet IP ranges. For example, 10.0.0.0/16.
  - name: --service-cidrs
    type: string
    short-summary: A comma separated list of CIDR notation IP ranges from which to assign service cluster IPs.
    long-summary: Each range must not overlap with any Subnet IP ranges. For example, "10.0.0.0/16,2001:abcd::/108".
  - name: --pod-cidrs
    type: string
    short-summary: A comma separated list of CIDR notation IP ranges from which to assign pod IPs when kubenet is used.
    long-summary: Each range must not overlap with any Subnet IP ranges. For example, "172.244.0.0/16,fd0:abcd::/64".
  - name: --ip-families
    type: string
    short-summary: A comma separated list of IP versions to use for cluster networking.
    long-summary: Each IP version should be in the format IPvN. For example, IPv4.
  - name: --vnet-subnet-id
    type: string
    short-summary: The ID of a subnet in an existing VNet into which to deploy the cluster.
  - name: --pod-subnet-id
    type: string
    short-summary: The ID of a subnet in an existing VNet into which to assign pods in the cluster (requires azure network-plugin).
  - name: --ppg
    type: string
    short-summary: The ID of a PPG.
  - name: --enable-node-public-ip
    type: bool
    short-summary: Enable VMSS node public IP.
  - name: --node-public-ip-prefix-id
    type: string
    short-summary: Public IP prefix ID used to assign public IPs to VMSS nodes.
  - name: --workspace-resource-id
    type: string
    short-summary: The resource ID of an existing Log Analytics Workspace to use for storing monitoring data. If not specified, uses the default Log Analytics Workspace if it exists, otherwise creates one.
  - name: --enable-msi-auth-for-monitoring
    type: bool
    short-summary: Enable Managed Identity Auth for Monitoring addon.
  - name: --enable-syslog
    type: bool
    short-summary: Enable syslog data collection for Monitoring addon
  - name: --data-collection-settings
    type: string
    short-summary: Path to JSON file containing data collection settings for Monitoring addon.
  - name: --uptime-sla
    type: bool
    short-summary: --uptime-sla is deprecated. Please use '--tier standard' instead.
  - name: --tier
    type: string
    short-summary: Specify SKU tier for managed clusters. '--tier standard' enables a standard managed cluster service with a financially backed SLA. '--tier free' does not have a financially backed SLA.
  - name: --attach-acr
    type: string
    short-summary: Grant the 'acrpull' role assignment to the ACR specified by name or resource ID.
  - name: --enable-private-cluster
    type: string
    short-summary: Enable private cluster.
  - name: --private-dns-zone
    type: string
    short-summary: Private dns zone mode for private cluster.
    long-summary: Allowed values are "system", "none" or custom private dns zone resource id. If not set, defaults to type system. Requires --enable-private-cluster to be used.
  - name: --fqdn-subdomain
    type: string
    short-summary: Prefix for FQDN that is created for private cluster with custom private dns zone scenario.
  - name: --disable-public-fqdn
    type: bool
    short-summary: Disable public fqdn feature for private cluster.
  - name: --api-server-authorized-ip-ranges
    type: string
    short-summary: Comma seperated list of authorized apiserver IP ranges. Set to 0.0.0.0/32 to restrict apiserver traffic to node pools.
  - name: --enable-managed-identity
    type: bool
    short-summary: Using a system assigned managed identity to manage cluster resource group.
  - name: --assign-identity
    type: string
    short-summary: Specify an existing user assigned identity for control plane's usage in order to manage cluster resource group.
  - name: --assign-kubelet-identity
    type: string
    short-summary: Specify an existing user assigned identity for kubelet's usage, which is typically used to pull image from ACR.
  - name: --node-osdisk-diskencryptionset-id -d
    type: string
    short-summary: ResourceId of the disk encryption set to use for enabling encryption at rest on agent node os disk.
  - name: --enable-workload-identity
    type: bool
    short-summary: Enable workload identity addon.
  - name: --aci-subnet-name
    type: string
    short-summary: The name of a subnet in an existing VNet into which to deploy the virtual nodes.
  - name: --appgw-name
    type: string
    short-summary: Name of the application gateway to create/use in the node resource group. Use with ingress-azure addon.
  - name: --appgw-subnet-cidr
    type: string
    short-summary: Subnet CIDR to use for a new subnet created to deploy the Application Gateway. Use with ingress-azure addon.
  - name: --appgw-id
    type: string
    short-summary: Resource Id of an existing Application Gateway to use with AGIC. Use with ingress-azure addon.
  - name: --appgw-subnet-id
    type: string
    short-summary: Resource Id of an existing Subnet used to deploy the Application Gateway. Use with ingress-azure addon.
  - name: --appgw-watch-namespace
    type: string
    short-summary: Specify the namespace, which AGIC should watch. This could be a single string value, or a comma-separated list of namespaces.
  - name: --enable-sgxquotehelper
    type: bool
    short-summary: Enable SGX quote helper for confcom addon.
  - name: --enable-encryption-at-host
    type: bool
    short-summary: Enable EncryptionAtHost, default value is false.
  - name: --enable-ultra-ssd
    type: bool
    short-summary: Enable UltraSSD, default value is false.
  - name: --enable-azure-rbac
    type: bool
    short-summary: Enable Azure RBAC to control authorization checks on cluster.
  - name: --edge-zone
    type: string
    short-summary: The name of the Edge Zone.
  - name: --disable-local-accounts
    type: bool
    short-summary: If set to true, getting static credential will be disabled for this cluster.
  - name: --tags
    type: string
    short-summary: The tags of the managed cluster. The managed cluster instance and all resources managed by the cloud provider will be tagged.
  - name: --aks-custom-headers
    type: string
    short-summary: Comma-separated key-value pairs to specify custom headers.
  - name: --enable-secret-rotation
    type: bool
    short-summary: Enable secret rotation. Use with azure-keyvault-secrets-provider addon.
  - name: --rotation-poll-interval
    type: string
    short-summary: Set interval of rotation poll. Use with azure-keyvault-secrets-provider addon.
  - name: --enable-fips-image
    type: bool
    short-summary: Use FIPS-enabled OS on agent nodes.
  - name: --enable-windows-gmsa
    type: bool
    short-summary: Enable Windows gmsa.
  - name: --gmsa-dns-server
    type: string
    short-summary: Specify DNS server for Windows gmsa for this cluster.
    long-summary: |-
        You do not need to set this if you have set DNS server in the VNET used by the cluster.
        You must set or not set --gmsa-dns-server and --gmsa-root-domain-name at the same time when setting --enable-windows-gmsa.
  - name: --gmsa-root-domain-name
    type: string
    short-summary: Specify root domain name for Windows gmsa for this cluster.
    long-summary: |-
        You do not need to set this if you have set DNS server in the VNET used by the cluster.
        You must set or not set --gmsa-dns-server and --gmsa-root-domain-name at the same time when setting --enable-windows-gmsa.
  - name: --snapshot-id
    type: string
    short-summary: The source snapshot id used to create this cluster.
  - name: --kubelet-config
    type: string
    short-summary: Path to JSON file containing Kubelet configurations for agent nodes. https://aka.ms/aks/custom-node-config
  - name: --linux-os-config
    type: string
    short-summary: Path to JSON file containing OS configurations for Linux agent nodes. https://aka.ms/aks/custom-node-config
  - name: --node-resource-group
    type: string
    short-summary: The node resource group is the resource group where all customer's resources will be created in, such as virtual machines.
  - name: --enable-defender
    type: bool
    short-summary: Enable Microsoft Defender security profile.
  - name: --defender-config
    type: string
    short-summary: Path to JSON file containing Microsoft Defender profile configurations.
  - name: --host-group-id
    type: string
    short-summary: The fully qualified dedicated host group id used to provision agent node pool.
  - name: --enable-azure-keyvault-kms
    type: bool
    short-summary: Enable Azure KeyVault Key Management Service.
  - name: --azure-keyvault-kms-key-id
    type: string
    short-summary: Identifier of Azure Key Vault key.
  - name: --azure-keyvault-kms-key-vault-network-access
    type: string
    short-summary: Network Access of Azure Key Vault.
    long-summary: Allowed values are "Public", "Private". If not set, defaults to type "Public". Requires --azure-keyvault-kms-key-id to be used.
  - name: --azure-keyvault-kms-key-vault-resource-id
    type: string
    short-summary: Resource ID of Azure Key Vault.
  - name: --enable-image-cleaner
    type: bool
    short-summary: Enable ImageCleaner Service.
  - name: --image-cleaner-interval-hours
    type: int
    short-summary: ImageCleaner scanning interval.
  - name: --disable-disk-driver
    type: bool
    short-summary: Disable AzureDisk CSI Driver.
  - name: --disable-file-driver
    type: bool
    short-summary: Disable AzureFile CSI Driver.
  - name: --disable-snapshot-controller
    type: bool
    short-summary: Disable CSI Snapshot Controller.
  - name: --enable-blob-driver
    type: bool
    short-summary: Enable AzureBlob CSI Driver.
  - name: --http-proxy-config
    type: string
    short-summary: HTTP Proxy configuration for this cluster.
  - name: --gpu-instance-profile
    type: string
    short-summary: GPU instance profile to partition multi-gpu Nvidia GPUs.
  - name: --enable-oidc-issuer
    type: bool
    short-summary: Enable OIDC issuer.
  - name: --enable-keda
    type: bool
    short-summary: Enable KEDA workload auto-scaler.
  - name: --enable-azure-monitor-metrics
    type: bool
    short-summary: Enable Azure Monitor Metrics Profile
  - name: --azure-monitor-workspace-resource-id
    type: string
    short-summary: Resource ID of the Azure Monitor Workspace
  - name: --ksm-metric-labels-allow-list
    type: string
    short-summary: Comma-separated list of additional Kubernetes label keys that will be used in the resource' labels metric. By default the metric contains only name and namespace labels. To include additional labels provide a list of resource names in their plural form and Kubernetes label keys you would like to allow for them (e.g. '=namespaces=[k8s-label-1,k8s-label-n,...],pods=[app],...)'. A single '*' can be provided per resource instead to allow any labels, but that has severe performance implications (e.g. '=pods=[*]').
  - name: --ksm-metric-annotations-allow-list
    type: string
    short-summary: Comma-separated list of additional Kubernetes label keys that will be used in the resource' labels metric. By default the metric contains only name and namespace labels. To include additional labels provide a list of resource names in their plural form and Kubernetes label keys you would like to allow for them (e.g.'=namespaces=[k8s-label-1,k8s-label-n,...],pods=[app],...)'. A single '*' can be provided per resource instead to allow any labels, but that has severe performance implications (e.g. '=pods=[*]').
  - name: --grafana-resource-id
    type: string
    short-summary: Resource ID of the Azure Managed Grafana Workspace
  - name: --enable-windows-recording-rules
    type: bool
    short-summary: Enable Windows Recording Rules when enabling the Azure Monitor Metrics addon

examples:
  - name: Create a Kubernetes cluster with an existing SSH public key.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --ssh-key-value /path/to/publickey
  - name: Create a Kubernetes cluster with a specific version.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --kubernetes-version 1.16.9
  - name: Create a Kubernetes cluster with a larger node pool.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --node-count 7
  - name: Create a kubernetes cluster with k8s 1.13.9 but use vmas.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --kubernetes-version 1.16.9 --vm-set-type AvailabilitySet
  - name: Create a kubernetes cluster with default kubernetes version, default SKU load balancer (Standard) and default vm set type (VirtualMachineScaleSets).
    text: az aks create -g MyResourceGroup -n MyManagedCluster
  - name: Create a kubernetes cluster with standard SKU load balancer and two AKS created IPs for the load balancer outbound connection usage.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-managed-outbound-ip-count 2
  - name: Create a kubernetes cluster with a standard SKU load balancer, with two outbound AKS managed IPs an idle flow timeout of 5 minutes and 8000 allocated ports per machine
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-managed-outbound-ip-count 2 --load-balancer-idle-timeout 5 --load-balancer-outbound-ports 8000
  - name: Create a kubernetes cluster with standard SKU load balancer and use the provided public IPs for the load balancer outbound connection usage.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-outbound-ips <ip-resource-id-1,ip-resource-id-2>
  - name: Create a kubernetes cluster with standard SKU load balancer and use the provided public IP prefixes for the load balancer outbound connection usage.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-outbound-ip-prefixes <ip-prefix-resource-id-1,ip-prefix-resource-id-2>
  - name: Create a kubernetes cluster with a AKS managed NAT gateway, with two outbound AKS managed IPs an idle flow timeout of 4 minutes
    text: az aks create -g MyResourceGroup -n MyManagedCluster --nat-gateway-managed-outbound-ip-count 2 --nat-gateway-idle-timeout 4 --outbound-type managedNATGateway --generate-ssh-keys
  - name: Create a kubernetes cluster with basic SKU load balancer and AvailabilitySet vm set type.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-sku basic --vm-set-type AvailabilitySet
  - name: Create a kubernetes cluster with authorized apiserver IP ranges.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --api-server-authorized-ip-ranges 193.168.1.0/24,194.168.1.0/24,195.168.1.0
  - name: Create a kubernetes cluster which enables managed identity.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-managed-identity
  - name: Create a kubernetes cluster with userDefinedRouting, standard load balancer SKU and a custom subnet preconfigured with a route table
    text: az aks create -g MyResourceGroup -n MyManagedCluster --outbound-type userDefinedRouting --load-balancer-sku standard --vnet-subnet-id customUserSubnetVnetID
  - name: Create a kubernetes cluster with supporting Windows agent pools.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-sku Standard --network-plugin azure --windows-admin-username azure --windows-admin-password 'replacePassword1234$'
  - name: Create a kubernetes cluster with supporting Windows agent pools with AHUB enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-sku Standard --network-plugin azure --windows-admin-username azure --windows-admin-password 'replacePassword1234$' --enable-ahub
  - name: Create a kubernetes cluster with managed AAD enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-aad --aad-admin-group-object-ids <id-1,id-2> --aad-tenant-id <id>
  - name: Create a kubernetes cluster with server side encryption using your owned key.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --node-osdisk-diskencryptionset-id <disk-encryption-set-resource-id>
  - name: Create a kubernetes cluster with ephemeral OS enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --node-osdisk-type Ephemeral --node-osdisk-size 48
  - name: Create a kubernetes cluster with EncryptionAtHost enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-encryption-at-host
  - name: Create a kubernetes cluster with UltraSSD enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-ultra-ssd
  - name: Create a kubernetes cluster with Azure RBAC enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-aad --enable-azure-rbac
  - name: Create a kubernetes cluster with custom control plane identity and kubelet identity.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --assign-identity <control-plane-identity-resource-id> --assign-kubelet-identity <kubelet-identity-resource-id>
  - name: Create a kubernetes cluster in the Edge Zone.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --location <location> --kubernetes-version 1.20.7 --edge-zone <edge-zone-name>
  - name: Create a kubernetes cluster with a specific OS SKU
    text: az aks create -g MyResourceGroup -n MyManagedCluster --os-sku Ubuntu
  - name: Create a kubernetes cluster with custom tags
    text: az aks create -g MyResourceGroup -n MyManagedCluster --tags "foo=bar" "baz=qux"
  - name: Create a kubernetes cluster with custom headers
    text: az aks create -g MyResourceGroup -n MyManagedCluster --aks-custom-headers WindowsContainerRuntime=containerd
  - name: Create a kubernetes cluster with FIPS-enabled OS
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-fips-image
  - name: Create a kubernetes cluster with enabling Windows gmsa and with setting DNS server in the vnet used by the cluster.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-sku Standard --network-plugin azure --windows-admin-username azure --windows-admin-password 'replacePassword1234$' --enable-windows-gmsa
  - name: Create a kubernetes cluster with enabling Windows gmsa but without setting DNS server in the vnet used by the cluster.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --load-balancer-sku Standard --network-plugin azure --windows-admin-username azure --windows-admin-password 'replacePassword1234$' --enable-windows-gmsa --gmsa-dns-server "10.240.0.4" --gmsa-root-domain-name "contoso.com"
  - name: create a kubernetes cluster with a snapshot id.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --kubernetes-version 1.20.9 --snapshot-id "/subscriptions/00000/resourceGroups/AnotherResourceGroup/providers/Microsoft.ContainerService/snapshots/mysnapshot1"
  - name: create a kubernetes cluster with support of hostgroup id.
    text: az aks create -g MyResourceGroup -n MyMC --kubernetes-version 1.20.13 --location westus2 --host-group-id /subscriptions/00000/resourceGroups/AnotherResourceGroup/providers/Microsoft.ContainerService/hostGroups/myHostGroup --node-vm-size VMSize --enable-managed-identity --assign-identity <user_assigned_identity_resource_id>
  - name: Create a kubernetes cluster with no CNI installed.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --network-plugin none
  - name: Create a kubernetes cluster with KEDA workload autoscaler enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-keda
  - name: Create a kubernetes cluster with Azure Monitor Metrics enabled.
    text: az aks create -g MyResourceGroup -n MyManagedCluster --enable-azure-monitor-metrics
"""

helps['aks update'] = """
type: command
short-summary: Update a managed Kubernetes cluster. When called with no optional arguments this attempts to move the cluster to its goal state without changing the current cluster configuration. This can be used to move out of a non succeeded state.
parameters:
  - name: --enable-cluster-autoscaler -e
    type: bool
    short-summary: Enable cluster autoscaler.
  - name: --disable-cluster-autoscaler -d
    type: bool
    short-summary: Disable cluster autoscaler.
  - name: --update-cluster-autoscaler -u
    type: bool
    short-summary: Update min-count or max-count for cluster autoscaler.
  - name: --min-count
    type: int
    short-summary: Minimum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [1, 1000]
  - name: --max-count
    type: int
    short-summary: Maximum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [1, 1000]
  - name: --uptime-sla
    type: bool
    short-summary: Enable a standard managed cluster service with a financially backed SLA. --uptime-sla is deprecated. Please use '--tier standard' instead.
  - name: --no-uptime-sla
    type: bool
    short-summary: Change a standard managed cluster to a free one. --no-uptime-sla is deprecated. Please use '--tier free' instead.
  - name: --tier
    type: string
    short-summary: Specify SKU tier for managed clusters. '--tier standard' enables a standard managed cluster service with a financially backed SLA. '--tier free' changes a standard managed cluster to a free one.
  - name: --network-plugin-mode
    type: string
    short-summary: Update the mode of a network plugin to migrate to a different pod networking setup.
  - name: --pod-cidr
    type: string
    short-summary: Update the pod CIDR for a cluster. Used when updating a cluster from Azure CNI to Azure CNI Overlay.
  - name: --load-balancer-managed-outbound-ip-count
    type: int
    short-summary: Load balancer managed outbound IP count.
    long-summary: Desired number of managed outbound IPs for load balancer outbound connection. Valid for Standard SKU load balancer cluster only. --load-balancer-managed-outbound-ip-count, --load-balancer-outbound-ips and --load-balancer-outbound-ip-prefixes are mutually exclusive. If updated, it will wipe off the existing setting on Load balancer outbound IP resource IDs and Load balancer outbound IP prefix resource IDs. If the new value is greater than the original value, new additional outbound IPs will be created. If the value is less than the original value, existing outbound IPs will be deleted and outbound connections may fail due to configuration update.
  - name: --load-balancer-managed-outbound-ipv6-count
    type: int
    short-summary: Load balancer managed outbound IPv6 IP count.
    long-summary: Desired number of managed outbound IPv6 IPs for load balancer outbound connection. Valid for dual-stack (--ip-families IPv4,IPv6) only. If updated, it will wipe off the existing setting on Load balancer managed outbound IPv6 count; Load balancer outbound IP resource IDs and Load balancer outbound IP prefix resource IDs.
  - name: --load-balancer-outbound-ips
    type: string
    short-summary: Load balancer outbound IP resource IDs.
    long-summary: Comma-separated public IP resource IDs for load balancer outbound connection. Valid for Standard SKU load balancer cluster only. --load-balancer-managed-outbound-ip-count, --load-balancer-outbound-ips and --load-balancer-outbound-ip-prefixes are mutually exclusive. If updated, it will wipe off the existing setting on Load balancer managed outbound IP count and Load balancer outbound IP prefix resource IDs.
  - name: --load-balancer-outbound-ip-prefixes
    type: string
    short-summary: Load balancer outbound IP prefix resource IDs.
    long-summary: Comma-separated public IP prefix resource IDs for load balancer outbound connection. Valid for Standard SKU load balancer cluster only. --load-balancer-managed-outbound-ip-count, --load-balancer-outbound-ips and --load-balancer-outbound-ip-prefixes are mutually exclusive. If updated, it will wipe off the existing setting on Load balancer managed outbound IP count and Load balancer outbound IP resource IDs.
  - name: --load-balancer-outbound-ports
    type: int
    short-summary: Load balancer outbound allocated ports.
    long-summary: Desired static number of outbound ports per VM in the load balancer backend pool. By default, set to 0 which uses the default allocation based on the number of VMs.
  - name: --load-balancer-idle-timeout
    type: int
    short-summary: Load balancer idle timeout in minutes.
    long-summary: Desired idle timeout for load balancer outbound flows, default is 30 minutes. Please specify a value in the range of [4, 100].
  - name: --nat-gateway-managed-outbound-ip-count
    type: int
    short-summary: NAT gateway managed outbound IP count.
    long-summary: Desired number of managed outbound IPs for NAT gateway outbound connection. Please specify a value in the range of [1, 16]. Valid for Standard SKU load balancer cluster with managedNATGateway outbound type only.
  - name: --nat-gateway-idle-timeout
    type: int
    short-summary: NAT gateway idle timeout in minutes.
    long-summary: Desired idle timeout for NAT gateway outbound flows, default is 4 minutes. Please specify a value in the range of [4, 120]. Valid for Standard SKU load balancer cluster with managedNATGateway outbound type only.
  - name: --auto-upgrade-channel
    type: string
    short-summary: Specify the upgrade channel for autoupgrade.
  - name: --attach-acr
    type: string
    short-summary: Grant the 'acrpull' role assignment to the ACR specified by name or resource ID.
  - name: --detach-acr
    type: string
    short-summary: Disable the 'acrpull' role assignment to the ACR specified by name or resource ID.
  - name: --api-server-authorized-ip-ranges
    type: string
    short-summary: Comma seperated list of authorized apiserver IP ranges. Set to "" to allow all traffic on a previously restricted cluster. Set to 0.0.0.0/32 to restrict apiserver traffic to node pools.
  - name: --enable-aad
    type: bool
    short-summary: Enable managed AAD feature for cluster.
  - name: --aad-admin-group-object-ids
    type: string
    short-summary: Comma seperated list of aad group object IDs that will be set as cluster admin.
  - name: --aad-tenant-id
    type: string
    short-summary: The ID of an Azure Active Directory tenant.
  - name: --enable-ahub
    type: bool
    short-summary: Enable Azure Hybrid User Benefits (AHUB) feature for cluster.
  - name: --disable-ahub
    type: bool
    short-summary: Disable Azure Hybrid User Benefits (AHUB) feature for cluster.
  - name: --windows-admin-password
    type: string
    short-summary: User account password to use on windows node VMs.
    long-summary: |-
      Rules for windows-admin-password:
          - Minimum-length: 14 characters
          - Max-length: 123 characters
          - Complexity requirements: 3 out of 4 conditions below need to be fulfilled
            * Has lower characters
            * Has upper characters
            * Has a digit
            * Has a special character (Regex match [\\W_])
          - Disallowed values:  "abc@123", "P@$$w0rd", "P@ssw0rd", "P@ssword123", "Pa$$word", "pass@word1", "Password!", "Password1", "Password22", "iloveyou!"
      Reference: https://docs.microsoft.com/dotnet/api/microsoft.azure.management.compute.models.virtualmachinescalesetosprofile.adminpassword?view=azure-dotnet
  - name: --enable-managed-identity
    type: bool
    short-summary: Update current cluster to use managed identity to manage cluster resource group.
  - name: --assign-identity
    type: string
    short-summary: Specify an existing user assigned identity to manage cluster resource group.
  - name: --assign-kubelet-identity
    type: string
    short-summary: Update cluster's kubelet identity to an existing user assigned identity. Please note this operation will recreate all agent nodes in the cluster.
  - name: --enable-azure-rbac
    type: bool
    short-summary: Enable Azure RBAC to control authorization checks on cluster.
  - name: --disable-azure-rbac
    type: bool
    short-summary: Disable Azure RBAC to control authorization checks on cluster.
  - name: --enable-public-fqdn
    type: bool
    short-summary: Enable public fqdn feature for private cluster.
  - name: --disable-public-fqdn
    type: bool
    short-summary: Disable public fqdn feature for private cluster.
  - name: --disable-local-accounts
    type: bool
    short-summary: If set to true, getting static credential will be disabled for this cluster.
  - name: --enable-local-accounts
    type: bool
    short-summary: If set to true, will enable getting static credential for this cluster.
  - name: --tags
    type: string
    short-summary: The tags of the managed cluster. The managed cluster instance and all resources managed by the cloud provider will be tagged.
  - name: --aks-custom-headers
    type: string
    short-summary: Comma-separated key-value pairs to specify custom headers.
  - name: --enable-workload-identity
    type: bool
    short-summary: Enable workload identity addon.
  - name: --disable-workload-identity
    type: bool
    short-summary: Disable workload identity addon.
  - name: --enable-secret-rotation
    type: bool
    short-summary: Enable secret rotation. Use with azure-keyvault-secrets-provider addon.
  - name: --disable-secret-rotation
    type: bool
    short-summary: Disable secret rotation. Use with azure-keyvault-secrets-provider addon.
  - name: --rotation-poll-interval
    type: string
    short-summary: Set interval of rotation poll. Use with azure-keyvault-secrets-provider addon.
  - name: --enable-windows-gmsa
    type: bool
    short-summary: Enable Windows gmsa on cluster.
  - name: --gmsa-dns-server
    type: string
    short-summary: Specify DNS server for Windows gmsa on cluster.
    long-summary: |-
        You do not need to set this if you have set DNS server in the VNET used by the cluster.
        You must set or not set --gmsa-dns-server and --gmsa-root-domain-name at the same time when setting --enable-windows-gmsa.
  - name: --gmsa-root-domain-name
    type: string
    short-summary: Specify root domain name for Windows gmsa on cluster.
    long-summary: |-
        You do not need to set this if you have set DNS server in the VNET used by the cluster.
        You must set or not set --gmsa-dns-server and --gmsa-root-domain-name at the same time when setting --enable-windows-gmsa.
  - name: --enable-defender
    type: bool
    short-summary: Enable Microsoft Defender security profile.
  - name: --disable-defender
    type: bool
    short-summary: Disable defender profile.
  - name: --defender-config
    type: string
    short-summary: Path to JSON file containing Microsoft Defender profile configurations.
  - name: --enable-azure-keyvault-kms
    type: bool
    short-summary: Enable Azure KeyVault Key Management Service.
  - name: --disable-azure-keyvault-kms
    type: bool
    short-summary: Disable Azure KeyVault Key Management Service.
  - name: --azure-keyvault-kms-key-id
    type: string
    short-summary: Identifier of Azure Key Vault key.
  - name: --azure-keyvault-kms-key-vault-network-access
    type: string
    short-summary: Network Access of Azure Key Vault.
    long-summary: Allowed values are "Public", "Private". If not set, defaults to type "Public". Requires --azure-keyvault-kms-key-id to be used.
  - name: --azure-keyvault-kms-key-vault-resource-id
    type: string
    short-summary: Resource ID of Azure Key Vault.
  - name: --enable-image-cleaner
    type: bool
    short-summary: Enable ImageCleaner Service.
  - name: --disable-image-cleaner
    type: bool
    short-summary: Disable ImageCleaner Service.
  - name: --image-cleaner-interval-hours
    type: int
    short-summary: ImageCleaner scanning interval.
  - name: --enable-disk-driver
    type: bool
    short-summary: Enable AzureDisk CSI Driver.
  - name: --disable-disk-driver
    type: bool
    short-summary: Disable AzureDisk CSI Driver.
  - name: --enable-file-driver
    type: bool
    short-summary: Enable AzureFile CSI Driver.
  - name: --disable-file-driver
    type: bool
    short-summary: Disable AzureFile CSI Driver.
  - name: --enable-snapshot-controller
    type: bool
    short-summary: Enable Snapshot Controller.
  - name: --disable-snapshot-controller
    type: bool
    short-summary: Disable CSI Snapshot Controller.
  - name: --enable-blob-driver
    type: bool
    short-summary: Enable AzureBlob CSI Driver.
  - name: --disable-blob-driver
    type: bool
    short-summary: Disable AzureBlob CSI Driver.
  - name: --http-proxy-config
    type: string
    short-summary: HTTP Proxy configuration for this cluster.
  - name: --enable-oidc-issuer
    type: bool
    short-summary: Enable OIDC issuer.
  - name: --enable-keda
    type: bool
    short-summary: Enable KEDA workload auto-scaler.
  - name: --disable-keda
    type: bool
    short-summary: Disable KEDA workload auto-scaler.
  - name: --enable-azure-monitor-metrics
    type: bool
    short-summary: Enable Azure Monitor Metrics Profile
  - name: --azure-monitor-workspace-resource-id
    type: string
    short-summary: Resource ID of the Azure Monitor Workspace
  - name: --ksm-metric-labels-allow-list
    type: string
    short-summary: Comma-separated list of additional Kubernetes label keys that will be used in the resource' labels metric. By default the metric contains only name and namespace labels. To include additional labels provide a list of resource names in their plural form and Kubernetes label keys you would like to allow for them (e.g. '=namespaces=[k8s-label-1,k8s-label-n,...],pods=[app],...)'. A single '*' can be provided per resource instead to allow any labels, but that has severe performance implications (e.g. '=pods=[*]').
  - name: --ksm-metric-annotations-allow-list
    type: string
    short-summary: Comma-separated list of additional Kubernetes label keys that will be used in the resource' labels metric. By default the metric contains only name and namespace labels. To include additional labels provide a list of resource names in their plural form and Kubernetes label keys you would like to allow for them (e.g.'=namespaces=[k8s-label-1,k8s-label-n,...],pods=[app],...)'. A single '*' can be provided per resource instead to allow any labels, but that has severe performance implications (e.g. '=pods=[*]').
  - name: --grafana-resource-id
    type: string
    short-summary: Resource ID of the Azure Managed Grafana Workspace
  - name: --enable-windows-recording-rules
    type: bool
    short-summary: Enable Windows Recording Rules when enabling the Azure Monitor Metrics addon
  - name: --disable-azure-monitor-metrics
    type: bool
    short-summary: Disable Azure Monitor Metrics Profile. This will delete all DCRA's associated with the cluster, any linked DCRs with the data stream = prometheus-stream and the recording rule groups created by the addon for this AKS cluster.

examples:
  - name: Reconcile the cluster back to its current state.
    text: az aks update -g MyResourceGroup -n MyManagedCluster
  - name: Update a kubernetes cluster with standard SKU load balancer to use two AKS created IPs for the load balancer outbound connection usage.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --load-balancer-managed-outbound-ip-count 2
  - name: Update a kubernetes cluster with standard SKU load balancer to use the provided public IPs for the load balancer outbound connection usage.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --load-balancer-outbound-ips <ip-resource-id-1,ip-resource-id-2>
  - name: Update a kubernetes cluster with a standard SKU load balancer, with two outbound AKS managed IPs an idle flow timeout of 5 minutes and 8000 allocated ports per machine
    text: az aks update -g MyResourceGroup -n MyManagedCluster --load-balancer-managed-outbound-ip-count 2 --load-balancer-idle-timeout 5 --load-balancer-outbound-ports 8000
  - name: Update a kubernetes cluster with standard SKU load balancer to use the provided public IP prefixes for the load balancer outbound connection usage.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --load-balancer-outbound-ip-prefixes <ip-prefix-resource-id-1,ip-prefix-resource-id-2>
  - name: Update a kubernetes cluster of managedNATGateway outbound type with two outbound AKS managed IPs an idle flow timeout of 4 minutes
    text: az aks update -g MyResourceGroup -n MyManagedCluster --nat-gateway-managed-outbound-ip-count 2 --nat-gateway-idle-timeout 4
  - name: Attach AKS cluster to ACR by name "acrName"
    text: az aks update -g MyResourceGroup -n MyManagedCluster --attach-acr acrName
  - name: Update a kubernetes cluster with authorized apiserver ip ranges.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --api-server-authorized-ip-ranges 193.168.1.0/24,194.168.1.0/24
  - name: Disable authorized apiserver ip ranges feature for a kubernetes cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --api-server-authorized-ip-ranges ""
  - name: Restrict apiserver traffic in a kubernetes cluster to agentpool nodes.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --api-server-authorized-ip-ranges 0.0.0.0/32
  - name: Update a AKS-managed AAD cluster with tenant ID or admin group object IDs.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --aad-admin-group-object-ids <id-1,id-2> --aad-tenant-id <id>
  - name: Migrate a AKS AAD-Integrated cluster or a non-AAD cluster to a AKS-managed AAD cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-aad --aad-admin-group-object-ids <id-1,id-2> --aad-tenant-id <id>
  - name: Enable Azure Hybrid User Benefits featture for a kubernetes cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-ahub
  - name: Disable Azure Hybrid User Benefits featture for a kubernetes cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --disable-ahub
  - name: Update Windows password of a kubernetes cluster
    text: az aks update -g MyResourceGroup -n MyManagedCLuster --windows-admin-password "Repl@cePassw0rd12345678"
  - name: Update the cluster to use system assigned managed identity in control plane.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-managed-identity
  - name: Update the cluster to use user assigned managed identity in control plane.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-managed-identity --assign-identity <user_assigned_identity_resource_id>
  - name: Update a non managed AAD AKS cluster to use Azure RBAC
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-aad --enable-azure-rbac
  - name: Update a managed AAD AKS cluster to use Azure RBAC
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-azure-rbac
  - name: Disable Azure RBAC in a managed AAD AKS cluster
    text: az aks update -g MyResourceGroup -n MyManagedCluster --disable-azure-rbac
  - name: Update the tags of a kubernetes cluster
    text: az aks update -g MyResourceGroup -n MyManagedCLuster --tags "foo=bar" "baz=qux"
  - name: Update a kubernetes cluster with custom headers
    text: az aks update -g MyResourceGroup -n MyManagedCluster --aks-custom-headers WindowsContainerRuntime=containerd,AKSHTTPCustomFeatures=Microsoft.ContainerService/CustomNodeConfigPreview
  - name: Enable Windows gmsa for a kubernetes cluster with setting DNS server in the vnet used by the cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-windows-gmsa
  - name: Enable Windows gmsa for a kubernetes cluster without setting DNS server in the vnet used by the cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-windows-gmsa --gmsa-dns-server "10.240.0.4" --gmsa-root-domain-name "contoso.com"
  - name: Enable KEDA workload autoscaler for an existing kubernetes cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --enable-keda
  - name: Disable KEDA workload autoscaler for an existing kubernetes cluster.
    text: az aks update -g MyResourceGroup -n MyManagedCluster --disable-keda
"""

helps['aks delete'] = """
type: command
short-summary: Delete a managed Kubernetes cluster.
examples:
  - name: Delete a managed Kubernetes cluster. (autogenerated)
    text: az aks delete --name MyManagedCluster --resource-group MyResourceGroup
    crafted: true
"""

helps['aks disable-addons'] = """
type: command
short-summary: Disable Kubernetes addons.
parameters:
  - name: --addons -a
    type: string
    short-summary: Disable the Kubernetes addons in a comma-separated list.
examples:
  - name: Disable Kubernetes addons. (autogenerated)
    text: az aks disable-addons --addons virtual-node --name MyManagedCluster --resource-group MyResourceGroup
    crafted: true
"""

helps['aks enable-addons'] = """
type: command
short-summary: Enable Kubernetes addons.
long-summary: |-
    These addons are available:
        - http_application_routing : configure ingress with automatic public DNS name creation.
        - monitoring               : turn on Log Analytics monitoring. Requires "--workspace-resource-id".
                                     Requires "--enable-msi-auth-for-monitoring" for managed identity auth.
                                     Requires "--enable-syslog" to enable syslog data collection from nodes. Note MSI must be enabled
                                     If monitoring addon is enabled --no-wait argument will have no effect
        - virtual-node             : enable AKS Virtual Node. Requires --subnet-name to provide the name of an existing subnet for the Virtual Node to use.
        - azure-policy             : enable Azure policy. The Azure Policy add-on for AKS enables at-scale enforcements and safeguards on your clusters in a centralized, consistent manner.
                                     Learn more at aka.ms/aks/policy.
        - ingress-appgw            : enable Application Gateway Ingress Controller addon.
        - open-service-mesh        : enable Open Service Mesh addon.
        - azure-keyvault-secrets-provider : enable Azure Keyvault Secrets Provider addon.
parameters:
  - name: --addons -a
    type: string
    short-summary: Enable the Kubernetes addons in a comma-separated list.
  - name: --workspace-resource-id
    type: string
    short-summary: The resource ID of an existing Log Analytics Workspace to use for storing monitoring data.
  - name: --enable-msi-auth-for-monitoring
    type: bool
    short-summary: Enable Managed Identity Auth for Monitoring addon.
  - name: --enable-syslog
    type: bool
    short-summary: Enable syslog data collection for Monitoring addon
  - name: --data-collection-settings
    type: string
    short-summary: Path to JSON file containing data collection settings for Monitoring addon.
  - name: --appgw-name
    type: string
    short-summary: Name of the application gateway to create/use in the node resource group. Use with ingress-azure addon.
  - name: --appgw-subnet-cidr
    type: string
    short-summary: Subnet CIDR to use for a new subnet created to deploy the Application Gateway. Use with ingress-azure addon.
  - name: --appgw-id
    type: string
    short-summary: Resource Id of an existing Application Gateway to use with AGIC. Use with ingress-azure addon.
  - name: --appgw-subnet-id
    type: string
    short-summary: Resource Id of an existing Subnet used to deploy the Application Gateway. Use with ingress-azure addon.
  - name: --appgw-watch-namespace
    type: string
    short-summary: Specify the namespace, which AGIC should watch. This could be a single string value, or a comma-separated list of namespaces.
  - name: --enable-sgxquotehelper
    type: bool
    short-summary: Enable SGX quote helper for confcom addon.
  - name: --enable-secret-rotation
    type: bool
    short-summary: Enable secret rotation. Use with azure-keyvault-secrets-provider addon.
  - name: --rotation-poll-interval
    type: string
    short-summary: Set interval of rotation poll. Use with azure-keyvault-secrets-provider addon.
examples:
  - name: Enable Kubernetes addons. (autogenerated)
    text: az aks enable-addons --addons virtual-node --name MyManagedCluster --resource-group MyResourceGroup --subnet MySubnetName
    crafted: true
  - name: Enable ingress-appgw addon with subnet prefix.
    text: az aks enable-addons --name MyManagedCluster --resource-group MyResourceGroup --addons ingress-appgw --appgw-subnet-cidr 10.225.0.0/16 --appgw-name gateway
    crafted: true
  - name: Enable open-service-mesh addon.
    text: az aks enable-addons --name MyManagedCluster --resource-group MyResourceGroup --addons open-service-mesh
    crafted: true
"""

helps['aks get-credentials'] = """
type: command
short-summary: Get access credentials for a managed Kubernetes cluster.
long-summary: By default, the credentials are merged into the .kube/config file so kubectl can use them.  See -f parameter for details.
parameters:
  - name: --admin -a
    type: bool
    short-summary: "Get cluster administrator credentials.  Default: cluster user credentials."
    long-summary: "On clusters with Azure Active Directory integration, this bypasses normal Azure AD authentication and can be used if you're permanently blocked by not having access to a valid Azure AD group with access to your cluster. Requires 'Azure Kubernetes Service Cluster Admin' role."
  - name: --file -f
    type: string
    short-summary: Kubernetes configuration file to update. Use "-" to print YAML to stdout instead.
  - name: --overwrite-existing
    type: bool
    short-summary: Overwrite any existing cluster entry with the same name.
  - name: --output -o
    type: string
    long-summary: Credentials are always in YAML format, so this argument is effectively ignored.
  - name: --public-fqdn
    type: bool
    short-summary: Get private cluster credential with server address to be public fqdn.
  - name: --format
    type: string
    short-summary: Specify the format of the returned credential. Available values are ["exec", "azure"].
                  Only take effect when requesting clusterUser credential of AAD clusters.
examples:
  - name: Get access credentials for a managed Kubernetes cluster. (autogenerated)
    text: az aks get-credentials --name MyManagedCluster --resource-group MyResourceGroup
    crafted: true
"""

helps['aks get-upgrades'] = """
type: command
short-summary: Get the upgrade versions available for a managed Kubernetes cluster.
examples:
  - name: Get the upgrade versions available for a managed Kubernetes cluster
    text: az aks get-upgrades --name MyManagedCluster --resource-group MyResourceGroup
    crafted: true
"""

helps['aks get-versions'] = """
type: command
short-summary: Get the versions available for creating a managed Kubernetes cluster.
examples:
  - name: Get the versions available for creating a managed Kubernetes cluster
    text: az aks get-versions --location westus2
    crafted: true
"""

helps['aks install-cli'] = """
type: command
short-summary: Download and install kubectl, the Kubernetes command-line tool. Download and install kubelogin, a client-go credential (exec) plugin implementing azure authentication.
"""

helps['aks list'] = """
type: command
short-summary: List managed Kubernetes clusters.
"""

helps['aks nodepool'] = """
type: group
short-summary: Commands to manage node pools in Kubernetes kubernetes cluster.
"""

helps['aks nodepool add'] = """
type: command
short-summary: Add a node pool to the managed Kubernetes cluster.
parameters:
  - name: --node-vm-size -s
    type: string
    short-summary: Size of Virtual Machines to create as Kubernetes nodes.
  - name: --node-count -c
    type: int
    short-summary: Number of nodes in the Kubernetes agent pool. After creating a cluster, you can change the size of its node pool with `az aks scale`.
  - name: --kubernetes-version -k
    type: string
    short-summary: Version of Kubernetes to use for creating the cluster, such as "1.16.9".
    populator-commands:
      - "`az aks get-versions`"
  - name: --node-osdisk-size
    type: int
    short-summary: Size in GB of the OS disk for each node in the agent pool. Minimum 30 GB.
  - name: --node-osdisk-type
    type: string
    short-summary: OS disk type to be used for machines in a given agent pool. Defaults to 'Ephemeral' when possible in conjunction with VM size and OS disk size. May not be changed for this pool after creation. ('Ephemeral' or 'Managed')
  - name: --max-pods -m
    type: int
    short-summary: The maximum number of pods deployable to a node.
    long-summary: If not specified, defaults based on network-plugin. 30 for "azure", 110 for "kubenet", or 250 for "none".
  - name: --zones -z
    type: string array
    short-summary: Availability zones where agent nodes will be placed. Also, to install agent nodes to more than one zone you need to pass zone numbers separated by blanks.  For example -  To have all 3 zones, you are expected to enter `--zones 1 2 3`
  - name: --enable-node-public-ip
    type: bool
    short-summary: Enable VMSS node public IP.
  - name: --node-public-ip-prefix-id
    type: string
    short-summary: Public IP prefix ID used to assign public IPs to VMSS nodes.
  - name: --vnet-subnet-id
    type: string
    short-summary: The Resource Id of a subnet in an existing VNet into which to deploy the cluster.
  - name: --pod-subnet-id
    type: string
    short-summary: The Resource Id of a subnet in an existing VNet into which to assign pods in the cluster (requires azure network-plugin).
  - name: --ppg
    type: string
    short-summary: The ID of a PPG.
  - name: --os-type
    type: string
    short-summary: The OS Type. Linux or Windows.
  - name: --os-sku
    type: string
    short-summary: The OS SKU of the agent node pool. Ubuntu or CBLMariner for Linux. Windows2019 or Windows2022 for Windows.
  - name: --enable-cluster-autoscaler -e
    type: bool
    short-summary: Enable cluster autoscaler.
  - name: --min-count
    type: int
    short-summary: Minimum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [0, 1000] for user nodepool, and [1,1000] for system nodepool.
  - name: --max-count
    type: int
    short-summary: Maximum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [0, 1000] for user nodepool, and [1,1000] for system nodepool.
  - name: --scale-down-mode
    type: string
    short-summary: "Describe how VMs are added to or removed from nodepools."
  - name: --node-taints
    type: string
    short-summary: The node taints for the node pool.
  - name: --labels
    type: string
    short-summary: The node labels for the node pool. See https://aka.ms/node-labels for syntax of labels.
  - name: --mode
    type: string
    short-summary: The mode for a node pool which defines a node pool's primary function. If set as "System", AKS prefers system pods scheduling to node pools with mode `System`. Learn more at https://aka.ms/aks/nodepool/mode.
  - name: --priority
    type: string
    short-summary: The priority of the node pool.
  - name: --eviction-policy
    type: string
    short-summary: The eviction policy of the Spot node pool. It can only be set when --priority is Spot.
  - name: --spot-max-price
    type: float
    short-summary: It can only be set when --priority is Spot. Specify the maximum price you are willing to pay in US Dollars. Possible values are any decimal value greater than zero or -1 which indicates default price to be up-to on-demand. It can only include up to 5 decimal places.
  - name: --max-surge
    type: string
    short-summary: Extra nodes used to speed upgrade. When specified, it represents the number or percent used, eg. 5 or 33%
  - name: --enable-encryption-at-host
    type: bool
    short-summary: Enable EncryptionAtHost, default value is false.
  - name: --enable-ultra-ssd
    type: bool
    short-summary: Enable UltraSSD, default value is false.
  - name: --enable-fips-image
    type: bool
    short-summary: Use FIPS-enabled OS on agent nodes.
  - name: --snapshot-id
    type: string
    short-summary: The source snapshot id used to create this nodepool.
  - name: --aks-custom-headers
    type: string
    short-summary: Comma-separated key-value pairs to specify custom headers.
  - name: --kubelet-config
    type: string
    short-summary: Path to JSON file containing Kubelet configurations for agent nodes. https://aka.ms/aks/custom-node-config
  - name: --linux-os-config
    type: string
    short-summary: Path to JSON file containing OS configurations for Linux agent nodes. https://aka.ms/aks/custom-node-config
  - name: --host-group-id
    type: string
    short-summary: The fully qualified dedicated host group id used to provision agent node pool.
  - name: --gpu-instance-profile
    type: string
    short-summary: GPU instance profile to partition multi-gpu Nvidia GPUs.
examples:
  - name: Create a nodepool in an existing AKS cluster with ephemeral os enabled.
    text: az aks nodepool add -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster --node-osdisk-type Ephemeral --node-osdisk-size 48
  - name: Create a nodepool with EncryptionAtHost enabled.
    text: az aks nodepool add -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster --enable-encryption-at-host
  - name: Create a nodepool with UltraSSD enabled.
    text: az aks nodepool add -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster --enable-ultra-ssd
  - name: Create a nodepool cluster with a specific OS SKU
    text: az aks nodepool add -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster --os-sku Ubuntu
  - name: Create a nodepool with FIPS-enabled OS
    text: az aks nodepool add -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster --enable-fips-image
  - name: create a kubernetes cluster with a snapshot id.
    text: az aks nodepool add -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster --kubernetes-version 1.20.9 --snapshot-id "/subscriptions/00000/resourceGroups/AnotherResourceGroup/providers/Microsoft.ContainerService/snapshots/mysnapshot1"
  - name: create a nodepool in an existing AKS cluster with host group id
    text: az aks nodepool add -g MyResourceGroup -n MyNodePool --cluster-name MyMC --host-group-id /subscriptions/00000/resourceGroups/AnotherResourceGroup/providers/Microsoft.ContainerService/hostGroups/myHostGroup --node-vm-size VMSize
"""

helps['aks nodepool delete'] = """
type: command
short-summary: Delete the agent pool in the managed Kubernetes cluster.
"""

helps['aks nodepool get-upgrades'] = """
type: command
short-summary: Get the available upgrade versions for an agent pool of the managed Kubernetes cluster.
examples:
  - name: Get the available upgrade versions for an agent pool of the managed Kubernetes cluster.
    text: az aks nodepool get-upgrades --resource-group MyResourceGroup --cluster-name MyManagedCluster --nodepool-name MyNodePool
    crafted: true
"""

helps['aks nodepool list'] = """
type: command
short-summary: List node pools in the managed Kubernetes cluster. To get list of nodes in the cluster run `kubectl get nodes` command.
"""

helps['aks nodepool scale'] = """
type: command
short-summary: Scale the node pool in a managed Kubernetes cluster.
parameters:
  - name: --node-count -c
    type: int
    short-summary: Number of nodes in the Kubernetes node pool.
"""

helps['aks nodepool show'] = """
type: command
short-summary: Show the details for a node pool in the managed Kubernetes cluster.
"""

helps['aks nodepool update'] = """
type: command
short-summary: Update a node pool properties.
long-summary: Update a node pool to enable/disable cluster-autoscaler or change min-count or max-count. When called with no optional arguments this attempts to move the node pool to its goal state without changing the current node pool configuration. This can be used to move out of a non succeeded state.
parameters:
  - name: --enable-cluster-autoscaler -e
    type: bool
    short-summary: Enable cluster autoscaler.
  - name: --disable-cluster-autoscaler -d
    type: bool
    short-summary: Disable cluster autoscaler.
  - name: --update-cluster-autoscaler -u
    type: bool
    short-summary: Update min-count or max-count for cluster autoscaler.
  - name: --min-count
    type: int
    short-summary: Minimum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [0, 1000] for user nodepool, and [1,1000] for system nodepool.
  - name: --max-count
    type: int
    short-summary: Maximum nodes count used for autoscaler, when "--enable-cluster-autoscaler" specified. Please specify the value in the range of [0, 1000] for user nodepool, and [1,1000] for system nodepool.
  - name: --scale-down-mode
    type: string
    short-summary: "Describe how VMs are added to or removed from nodepools."
  - name: --mode
    type: string
    short-summary: The mode for a node pool which defines a node pool's primary function. If set as "System", AKS prefers system pods scheduling to node pools with mode `System`. Learn more at https://aka.ms/aks/nodepool/mode.
  - name: --max-surge
    type: string
    short-summary: Extra nodes used to speed upgrade. When specified, it represents the number or percent used, eg. 5 or 33%
  - name: --node-taints
    type: string
    short-summary: The node taints for the node pool. You can update the existing node taint of a nodepool or create a new node taint for a nodepool. Pass the empty string `""` to remove all taints.
  - name: --labels
    type: string
    short-summary: The node labels for the node pool. See https://aka.ms/node-labels for syntax of labels.
  - name: --aks-custom-headers
    type: string
    short-summary: Comma-separated key-value pairs to specify custom headers.
examples:
  - name: Reconcile the nodepool back to its current state.
    text: az aks nodepool update -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster
  - name: Enable cluster-autoscaler within node count range [1,5]
    text: az aks nodepool update --enable-cluster-autoscaler --min-count 1 --max-count 5 -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster
  - name: Disable cluster-autoscaler for an existing cluster
    text: az aks nodepool update --disable-cluster-autoscaler -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster
  - name: Update min-count or max-count for cluster autoscaler.
    text: az aks nodepool update --update-cluster-autoscaler --min-count 1 --max-count 10 -g MyResourceGroup -n nodepool1 --cluster-name MyManagedCluster
"""

helps['aks nodepool upgrade'] = """
type: command
short-summary: Upgrade the node pool in a managed Kubernetes cluster.
parameters:
  - name: --kubernetes-version -k
    type: string
    short-summary: Version of Kubernetes to upgrade the node pool to, such as "1.16.9".
  - name: --node-image-only
    type: bool
    short-summary: Only upgrade agent pool's node image.
  - name: --max-surge
    type: string
    short-summary: Extra nodes used to speed upgrade. When specified, it represents the number or percent used, eg. 5 or 33% (mutually exclusive with "--node-image-only". See "az aks nodepool update --max-surge" to update max surge before upgrading with "--node-image-only")
  - name: --snapshot-id
    type: string
    short-summary: The source snapshot id used to upgrade this nodepool.
  - name: --aks-custom-headers
    type: string
    short-summary: Comma-separated key-value pairs to specify custom headers.
"""

helps['aks nodepool stop'] = """
    type: command
    short-summary: Stop running agent pool in the managed Kubernetes cluster.
    parameters:
        - name: --aks-custom-headers
          type: string
          short-summary: Send custom headers. When specified, format should be Key1=Value1,Key2=Value2
    examples:
        - name: Stop agent pool in the managed cluster
          text: az aks nodepool stop --nodepool-name nodepool1 -g MyResourceGroup --cluster-name MyManagedCluster
"""

helps['aks nodepool start'] = """
    type: command
    short-summary: Start stopped agent pool in the managed Kubernetes cluster.
    parameters:
        - name: --aks-custom-headers
          type: string
          short-summary: Send custom headers. When specified, format should be Key1=Value1,Key2=Value2
    examples:
        - name: Start agent pool in the managed cluster
          text: az aks nodepool start --nodepool-name nodepool1 -g MyResourceGroup --cluster-name MyManagedCluster
"""

helps['aks nodepool operation-abort'] = """
    type: command
    short-summary: Abort last running operation on nodepool.
    examples:
        - name: Abort operation on agent pool
          text: az aks nodepool operation-abort -g myResourceGroup --nodepool-name nodepool1 --cluster-name myAKSCluster
"""

helps['aks operation-abort'] = """
    type: command
    short-summary: Abort last running operation on managed cluster.
    examples:
        - name: Abort operation on managed cluster
          text: az aks operation-abort -g myResourceGroup -n myAKSCluster
"""

helps['aks remove-dev-spaces'] = """
type: command
short-summary: Remove Azure Dev Spaces from a managed Kubernetes cluster.
examples:
  - name: Remove Azure Dev Spaces from a managed Kubernetes cluster.
    text: |-
        az aks remove-dev-spaces -g my-aks-group -n my-aks
  - name: Remove Azure Dev Spaces from a managed Kubernetes cluster without prompting.
    text: |-
        az aks remove-dev-spaces -g my-aks-group -n my-aks --yes
"""

helps['aks scale'] = """
type: command
short-summary: Scale the node pool in a managed Kubernetes cluster.
parameters:
  - name: --node-count -c
    type: int
    short-summary: Number of nodes in the Kubernetes node pool.
examples:
  - name: Scale the node pool in a managed Kubernetes cluster. (autogenerated)
    text: az aks scale --name MyManagedCluster --node-count 3 --resource-group MyResourceGroup
    crafted: true
"""

helps['aks show'] = """
type: command
short-summary: Show the details for a managed Kubernetes cluster.
examples:
  - name: Show the details for a managed Kubernetes cluster
    text: az aks show --name MyManagedCluster --resource-group MyResourceGroup
    crafted: true
"""

helps['aks update-credentials'] = """
type: command
short-summary: Update credentials for a managed Kubernetes cluster, like service principal.
parameters:
  - name: --reset-service-principal
    type: bool
    short-summary: Reset service principal for a managed cluster.
  - name: --service-principal
    type: string
    short-summary: Service principal used for authentication to Azure APIs. This argument is required if `--reset-service-principal` is specified.
  - name: --client-secret
    type: string
    short-summary: Secret associated with the service principal. This argument is required if `--service-principal` is specified.
  - name: --reset-aad
    type: string
    short-summary: Reset Azure Active Directory configuration for a managed cluster.
    long-summary: --reset-aad is deprecated. See https://aka.ms/aks/aad-legacy for details.
  - name: --aad-server-app-id
    type: string
    short-summary: The ID of an Azure Active Directory server application. This argument is required if `--reset-aad` is specified.
    long-summary: --aad-server-app-id is deprecated. See https://aka.ms/aks/aad-legacy for details.
  - name: --aad-server-app-secret
    type: string
    short-summary: The secret of an Azure Active Directory server application. This argument is required if `--reset-aad` is specified.
    long-summary: --aad-server-app-secret is deprecated. See https://aka.ms/aks/aad-legacy for details.
  - name: --aad-client-app-id
    type: string
    short-summary: The ID of an Azure Active Directory client application. This argument is required if `--reset-aad` is specified.
    long-summary: --aad-client-app-id is deprecated. See https://aka.ms/aks/aad-legacy for details.
  - name: --aad-tenant-id
    type: string
    short-summary: Tenant ID associated with Azure Active Directory.

examples:
  - name: Update an existing Kubernetes cluster with new service principal.
    text: az aks update-credentials -g MyResourceGroup -n MyManagedCluster --reset-service-principal --service-principal MyNewServicePrincipalID --client-secret MyNewServicePrincipalSecret
"""

helps['aks upgrade'] = """
type: command
short-summary: Upgrade a managed Kubernetes cluster to a newer version.
long-summary: "Kubernetes will be unavailable during cluster upgrades."
parameters:
  - name: --kubernetes-version -k
    type: string
    short-summary: Version of Kubernetes to upgrade the cluster to, such as "1.16.9".
    populator-commands:
      - "`az aks get-upgrades`"
  - name: --control-plane-only
    type: bool
    short-summary: Upgrade the cluster control plane only. If not specified, both control plane AND all node pools will be upgraded.
  - name: --node-image-only
    type: bool
    short-summary: Only upgrade node image for agent pools.
examples:
  - name: Upgrade a managed Kubernetes cluster to a newer version. (autogenerated)
    text: az aks upgrade --kubernetes-version 1.12.6 --name MyManagedCluster --resource-group MyResourceGroup
    crafted: true
"""

helps['aks use-dev-spaces'] = """
type: command
short-summary: Use Azure Dev Spaces with a managed Kubernetes cluster.
parameters:
  - name: --update
    type: bool
    short-summary: Update to the latest Azure Dev Spaces client components.
  - name: --space -s
    type: string
    short-summary: Name of the new or existing dev space to select. Defaults to an interactive selection experience.
  - name: --endpoint -e
    type: string
    short-summary: The endpoint type to be used for a Azure Dev Spaces controller. See https://aka.ms/azds-networking for more information.
examples:
  - name: Use Azure Dev Spaces with a managed Kubernetes cluster, interactively selecting a dev space.
    text: |-
        az aks use-dev-spaces -g my-aks-group -n my-aks
  - name: Use Azure Dev Spaces with a managed Kubernetes cluster, updating to the latest Azure Dev Spaces \
            client components and selecting a new or existing dev space 'my-space'.
    text: |-
        az aks use-dev-spaces -g my-aks-group -n my-aks --update --space my-space
  - name: Use Azure Dev Spaces with a managed Kubernetes cluster, selecting a new or existing dev space \
            'develop/my-space' without prompting for confirmation.
    text: |-
        az aks use-dev-spaces -g my-aks-group -n my-aks -s develop/my-space -y
  - name: Use Azure Dev Spaces with a managed Kubernetes cluster with a private endpoint.
    text: |-
        az aks use-dev-spaces -g my-aks-group -n my-aks -e private
"""

helps['aks wait'] = """
type: command
short-summary: Wait for a managed Kubernetes cluster to reach a desired state.
long-summary: If an operation on a cluster was interrupted or was started with `--no-wait`, use this command to wait for it to complete.
examples:
  - name: Wait for a cluster to be upgraded, polling every minute for up to thirty minutes.
    text: |-
        az aks wait -g MyResourceGroup -n MyManagedCluster --updated --interval 60 --timeout 1800
  - name: Wait for a managed Kubernetes cluster to reach a desired state (autogenerated)
    text: az aks wait --created --interval 60 --name MyManagedCluster --resource-group MyResourceGroup --timeout 1800
    crafted: true
"""

helps['aks nodepool wait'] = """
type: command
short-summary: Wait for a node pool to reach a desired state.
long-summary: If an operation on a node pool was interrupted or was started with `--no-wait`, use this command to wait for it to complete.
examples:
  - name: Wait for a node pool to reach a desired state, polling every minute for up to thirty minutes.
    text: |-
        az aks nodepool wait --created --interval 60 --cluster-name MyManagedCluster --resource-group MyResourceGroup --nodepool-name MyNodePool --timeout 1800
"""

helps['aks nodepool snapshot wait'] = """
type: command
short-summary: Wait for a nodepool snapshot to reach a desired state.
long-summary: If an operation on a nodepool snapshot was interrupted or was started with `--no-wait`, use this command to wait for it to complete.
examples:
  - name: Wait for a node pool to reach a desired state, polling every minute for up to thirty minutes.
    text: |-
        az aks nodepool snapshot wait --created --interval 60 --name MySnapshot --resource-group MyResourceGroup --timeout 1800
"""

helps['aks rotate-certs'] = """
    type: command
    short-summary: Rotate certificates and keys on a managed Kubernetes cluster
    long-summary: Kubernetes will be unavailable during cluster certificate rotation.
"""

helps['aks command'] = """
    type: group
    short-summary: See detail usage in 'az aks command invoke', 'az aks command result'.
"""

helps['aks command invoke'] = """
    type: command
    short-summary: Run a shell command (with kubectl, helm) on your aks cluster, support attaching files as well.
    parameters:
        - name: --command -c
          type: string
          short-summary: Command or shell script you want to run.
        - name: --file -f
          type: string
          short-summary: Files to be used by the command, use '.' to attach the current folder.
"""

helps['aks command result'] = """
    type: command
    short-summary: Fetch result from previously triggered 'aks command invoke'.
    parameters:
        - name: --command-id -i
          type: string
          short-summary: commandId returned from 'aks command invoke'.
"""

helps['aks snapshot'] = """
    type: group
    short-summary: Commands to manage nodepool snapshots.
"""

helps['aks snapshot show'] = """
    type: command
    short-summary: Show the details of a nodepool snapshot.
"""

helps['aks snapshot list'] = """
    type: command
    short-summary: List nodepool snapshots.
"""

helps['aks snapshot create'] = """
    type: command
    short-summary: Create a nodepool snapshot.
    parameters:
        - name: --nodepool-id
          type: string
          short-summary: The source nodepool id from which to create this snapshot.
        - name: --tags
          type: string
          short-summary: The tags of the snapshot.
        - name: --aks-custom-headers
          type: string
          short-summary: Send custom headers. When specified, format should be Key1=Value1,Key2=Value2
"""

helps['aks snapshot delete'] = """
    type: command
    short-summary: Delete a nodepool snapshot.
"""

helps['aks snapshot wait'] = """
type: command
short-summary: Wait for a nodepool snapshot to reach a desired state.
long-summary: If an operation on a nodepool snapshot was interrupted or was started with `--no-wait`, use this command to wait for it to complete.
"""

helps['aks nodepool snapshot'] = """
    type: group
    short-summary: Commands to manage nodepool snapshots.
"""

helps['aks nodepool snapshot show'] = """
    type: command
    short-summary: Show the details of a nodepool snapshot.
"""

helps['aks nodepool snapshot list'] = """
    type: command
    short-summary: List nodepool snapshots.
"""

helps['aks nodepool snapshot create'] = """
    type: command
    short-summary: Create a nodepool snapshot.
    parameters:
        - name: --nodepool-id
          type: string
          short-summary: The source nodepool id from which to create this snapshot.
        - name: --tags
          type: string
          short-summary: The tags of the snapshot.
        - name: --aks-custom-headers
          type: string
          short-summary: Send custom headers. When specified, format should be Key1=Value1,Key2=Value2
    examples:
        - name: Create a nodepool snapshot.
          text: az aks nodepool snapshot create -g MyResourceGroup -n snapshot1 --nodepool-id "/subscriptions/00000/resourceGroups/AnotherResourceGroup/providers/Microsoft.ContainerService/managedClusters/akscluster1/agentPools/nodepool1"
        - name: Create a nodepool snapshot with custom tags.
          text: az aks nodepool snapshot create -g MyResourceGroup -n snapshot1 --nodepool-id "/subscriptions/00000/resourceGroups/AnotherResourceGroup/providers/Microsoft.ContainerService/managedClusters/akscluster1/agentPools/nodepool1" --tags "foo=bar" "key1=val1"
"""

helps['aks nodepool snapshot delete'] = """
    type: command
    short-summary: Delete a nodepool snapshot.
"""

helps['aks oidc-issuer'] = """
    type: group
    short-summary: oidc issuer related commands
"""
helps['aks oidc-issuer rotate-signing-keys'] = """
    type: command
    short-summary: Rotate oidc issuer service account signing keys
"""



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
#
# Code generated by aaz-dev-tools
# --------------------------------------------------------------------------------------------

# pylint: skip-file
# flake8: noqa

from azure.cli.core.aaz import *


@register_command_group(
    "policy-insights attestation",
)
class __CMDGroup(AAZCommandGroup):
    """Manage resource policy attestation.

    Attestations are used by Azure Policy to set compliance states of resources or scopes targeted by manual policies. They also allow users to provide additional metadata or link to evidence which accompanies the attested compliance state.
    """
    pass


__all__ = ["__CMDGroup"]
